==> plasma-framework-5.90.0.zip: plasma-framework-5.90.0/src/desktoptheme/breeze/metadata.desktop.cmake <==
[Desktop Entry]
Name=Breeze
Name[ar]=نسيم
Name[az]=Breeze
Name[ca]=Brisa
Name[ca@valencia]=Brisa
Name[cs]=Breeze
Name[da]=Breeze
Name[de]=Breeze
Name[en_GB]=Breeze
Name[es]=Brisa
Name[et]=Breeze
Name[eu]=Breeze
Name[fi]=Breeze
Name[fr]=Breeze
Name[gd]=Oiteag
Name[gl]=Breeze
Name[hu]=Breeze
Name[ia]=Brisa
Name[id]=Breeze
Name[it]=Brezza
Name[ko]=Breeze
Name[lt]=Breeze
Name[lv]=Brīze
Name[nb]=Bris
Name[nds]=Breeze
Name[nl]=Breeze
Name[nn]=Breeze
Name[pa]=ਬਰੀਜ਼
Name[pl]=Bryza
Name[pt]=Brisa
Name[pt_BR]=Breeze
Name[ro]=Briză
Name[ru]=Breeze
Name[sk]=Vánok
Name[sl]=Sapica
Name[sr]=Поветарац
Name[sr@ijekavian]=Поветарац
Name[sr@ijekavianlatin]=Povetarac
Name[sr@latin]=Povetarac
Name[sv]=Breeze
Name[tg]=Насим
Name[tr]=Esintili
Name[uk]=Breeze
Name[vi]=Breeze
Name[x-test]=xxBreezexx
Name[zh_CN]=Breeze 微风
Name[zh_TW]=Breeze
Comment=Breeze by the KDE VDG
Comment[ar]=نسيم من مجموعة تصميم كدي
Comment[az]=KDE VDG tərəfindən Breeze
Comment[ca]=Brisa, creat pel VDG del KDE
Comment[ca@valencia]=Brisa, creat pel VDG del KDE
Comment[cs]=Breeze od KDE VDG
Comment[da]=Breeze af KDE VDG
Comment[de]=Breeze von der KDE VDG
Comment[en_GB]=Breeze by the KDE VDG
Comment[es]=Brisa por KDE VDG
Comment[et]=Breeze KDE VDG-lt
Comment[eu]=Breeze, KDE VDGk egina
Comment[fi]=Breeze KDE VDG:ltä
Comment[fr]=Breeze, par KDE VDG
Comment[gl]=Breeze de KDE VDG
Comment[hu]=Breeze a KDE VDG-től
Comment[ia]=Breeze (Brisa) per le KDE VDG
Comment[id]=Breeze oleh KDE VDG
Comment[it]=Brezza del KDE VDG
Comment[ko]=KDE 시각 디자인 그룹에서 제작한 Breeze
Comment[nl]=Breeze door de KDE VDG
Comment[nn]=Breeze frå KDE VDG
Comment[pl]=Bryza autorstwa KDE VDG
Comment[pt]=Brisa da VDG do KDE
Comment[pt_BR]=Breeze pelo KDE VDG
Comment[ro]=Briză, de KDE VDG
Comment[ru]=Breeze от KDE VDG
Comment[sk]=Vánok od KDE VDG
Comment[sl]=Sapica (Breeze) od KDE VDG
Comment[sv]=Breeze av KDE:s visuella designgrupp
Comment[tg]=Насим аз KDE VDG
Comment[uk]=Breeze, автори — KDE VDG
Comment[vi]=Breeze, do KDE VDG
Comment[x-test]=xxBreeze by the KDE VDGxx
Comment[zh_CN]=Breeze 微风主题，由 KDE VDG (视觉设计团队) 设计制作
Comment[zh_TW]=由 KDE VDG 團隊製作的 Breeze


X-KDE-PluginInfo-Author=KDE Visual Design Group
X-KDE-PluginInfo-Email=kde-artists@kde.org
X-KDE-PluginInfo-Name=default
X-KDE-PluginInfo-Version=@KF_VERSION@
X-KDE-PluginInfo-Website=https://plasma.kde.org
X-KDE-PluginInfo-Category=
X-KDE-PluginInfo-License=LGPL
X-KDE-PluginInfo-EnabledByDefault=true
X-Plasma-API=5.0

[Wallpaper]
defaultWallpaperTheme=Next
defaultFileSuffix=.png
defaultWidth=1920
defaultHeight=1080

[ContrastEffect]
enabled=true
contrast=0.2
intensity=1.4
saturation=10

[AdaptiveTransparency]
enabled=true

==> plasma-framework-5.93.0.zip: plasma-framework-5.93.0/src/desktoptheme/breeze/metadata.desktop.cmake <==
[Desktop Entry]
Name=Breeze
Name[ar]=نسيم
Name[az]=Breeze
Name[ca]=Brisa
Name[ca@valencia]=Brisa
Name[cs]=Breeze
Name[da]=Breeze
Name[de]=Breeze
Name[en_GB]=Breeze
Name[es]=Brisa
Name[et]=Breeze
Name[eu]=Breeze
Name[fi]=Breeze
Name[fr]=Breeze
Name[gd]=Oiteag
Name[gl]=Breeze
Name[hu]=Breeze
Name[ia]=Brisa
Name[id]=Breeze
Name[it]=Brezza
Name[ko]=Breeze
Name[lt]=Breeze
Name[lv]=Brīze
Name[nb]=Bris
Name[nds]=Breeze
Name[nl]=Breeze
Name[nn]=Breeze
Name[pa]=ਬਰੀਜ਼
Name[pl]=Bryza
Name[pt]=Brisa
Name[pt_BR]=Breeze
Name[ro]=Briză
Name[ru]=Breeze
Name[sk]=Vánok
Name[sl]=Sapica
Name[sr]=Поветарац
Name[sr@ijekavian]=Поветарац
Name[sr@ijekavianlatin]=Povetarac
Name[sr@latin]=Povetarac
Name[sv]=Breeze
Name[tg]=Насим
Name[tr]=Esinti
Name[uk]=Breeze
Name[vi]=Breeze
Name[x-test]=xxBreezexx
Name[zh_CN]=Breeze 微风
Name[zh_TW]=Breeze
Comment=Breeze by the KDE VDG
Comment[ar]=نسيم من مجموعة تصميم كدي
Comment[az]=KDE VDG tərəfindən Breeze
Comment[ca]=Brisa, creat pel VDG del KDE
Comment[ca@valencia]=Brisa, creat pel VDG de KDE
Comment[cs]=Breeze od KDE VDG
Comment[da]=Breeze af KDE VDG
Comment[de]=Breeze von der KDE VDG
Comment[en_GB]=Breeze by the KDE VDG
Comment[es]=Brisa por KDE VDG
Comment[et]=Breeze KDE VDG-lt
Comment[eu]=Breeze, KDE VDGk egina
Comment[fi]=Breeze KDE VDG:ltä
Comment[fr]=Breeze, par KDE VDG
Comment[gl]=Breeze de KDE VDG
Comment[hu]=Breeze a KDE VDG-től
Comment[ia]=Breeze (Brisa) per le KDE VDG
Comment[id]=Breeze oleh KDE VDG
Comment[it]=Brezza del KDE VDG
Comment[ko]=KDE 시각 디자인 그룹에서 제작한 Breeze
Comment[nl]=Breeze door de KDE VDG
Comment[nn]=Breeze frå KDE VDG
Comment[pl]=Bryza autorstwa KDE VDG
Comment[pt]=Brisa da VDG do KDE
Comment[pt_BR]=Breeze pelo KDE VDG
Comment[ro]=Briză, de KDE VDG
Comment[ru]=Breeze от KDE VDG
Comment[sk]=Vánok od KDE VDG
Comment[sl]=Sapica (Breeze) od KDE VDG
Comment[sv]=Breeze av KDE:s visuella designgrupp
Comment[tg]=Насим аз KDE VDG
Comment[tr]=KDE VDG tarafından yapılan Esinti
Comment[uk]=Breeze, автори — KDE VDG
Comment[vi]=Breeze, do KDE VDG
Comment[x-test]=xxBreeze by the KDE VDGxx
Comment[zh_CN]=Breeze 微风主题，由 KDE VDG (视觉设计团队) 设计制作
Comment[zh_TW]=由 KDE VDG 團隊製作的 Breeze


X-KDE-PluginInfo-Author=KDE Visual Design Group
X-KDE-PluginInfo-Email=kde-artists@kde.org
X-KDE-PluginInfo-Name=default
X-KDE-PluginInfo-Version=@KF_VERSION@
X-KDE-PluginInfo-Website=https://plasma.kde.org
X-KDE-PluginInfo-Category=
X-KDE-PluginInfo-License=LGPL
X-KDE-PluginInfo-EnabledByDefault=true
X-Plasma-API=5.0

[Wallpaper]
defaultWallpaperTheme=Next
defaultFileSuffix=.png
defaultWidth=1920
defaultHeight=1080

[ContrastEffect]
enabled=true
contrast=0.2
intensity=1.4
saturation=10

[AdaptiveTransparency]
enabled=true
